@@ -5,7 +5,7 @@ from checkov.arm.registry import arm_resource_registry, arm_parameter_registry
 from checkov.arm.parser import parse
 from checkov.common.output.record import Record
 from checkov.common.output.report import Report
-from checkov.common.runners.base_runner import BaseRunner, filter_ignored_directories
+from checkov.common.runners.base_runner import BaseRunner, filter_ignored_paths
 from checkov.runner_filter import RunnerFilter
 from checkov.arm.parser.node import dict_node
 from checkov.arm.context_parser import ContextParser
@@ -32,7 +32,8 @@ class Runner(BaseRunner):
 
         if root_folder:
             for root, d_names, f_names in os.walk(root_folder):
-                filter_ignored_directories(d_names)
+                filter_ignored_paths(root, d_names, runner_filter.excluded_paths)
+                filter_ignored_paths(root, f_names, runner_filter.excluded_paths)
                 for file in f_names:
                     file_ending = os.path.splitext(file)[1]
                     if file_ending in ARM_POSSIBLE_ENDINGS:
@@ -97,7 +98,7 @@ class Runner(BaseRunner):
                             results = arm_resource_registry.scan(arm_file, {resource_name: resource}, skipped_checks,
                                                                  runner_filter)
                             for check, check_result in results.items():
-                                record = Record(check_id=check.id, check_name=check.name, check_result=check_result,
+                                record = Record(check_id=check.id, bc_check_id=check.bc_id, check_name=check.name, check_result=check_result,
                                                 code_block=entity_code_lines, file_path=arm_file,
                                                 file_line_range=entity_lines_range,
                                                 resource=resource_id, evaluations=variable_evaluations,
@@ -118,7 +119,7 @@ class Runner(BaseRunner):
                             skipped_checks = ContextParser.collect_skip_comments(parameter_details)
                             results = arm_parameter_registry.scan(arm_file, {resource_name: parameter_details}, skipped_checks, runner_filter)
                             for check, check_result in results.items():
-                                record = Record(check_id=check.id, check_name=check.name, check_result=check_result,
+                                record = Record(check_id=check.id, bc_check_id=check.bc_id, check_name=check.name, check_result=check_result,
                                                 code_block=entity_code_lines, file_path=arm_file,
                                                 file_line_range=entity_lines_range,
                                                 resource=resource_id, evaluations=variable_evaluations,
