@@ -11,6 +11,7 @@ class BaseIntegrationFeature(ABC):
     onboarding_url = f"{BC_API_URL}/signup/checkov"
     api_token_url = f"{BC_API_URL}/integrations/apiToken"
     suppressions_url = f"{BC_API_URL}/suppressions"
+    policies_url = f"{BC_API_URL}/policies/table/data"
     fixes_url = f"{BC_API_URL}/fixes/checkov"
 
     def __init__(self, bc_integration, order):
@@ -24,10 +25,14 @@ class BaseIntegrationFeature(ABC):
         raise NotImplementedError()
 
     def pre_scan(self):
-        # overriding is optional
+        """Runs before any runners"""
         pass
 
-    def post_scan(self, scan_reports):
-        # overriding is optional
+    def pre_runner(self):
+        """Runs before each runner"""
+        pass
+
+    def post_runner(self, scan_reports):
+        """Runs after each runner completes"""
         pass
 
