@@ -1,3 +1,4 @@
+import os.path
 from time import sleep
 
 import boto3
@@ -23,6 +24,7 @@ from checkov.common.bridgecrew.platform_key import read_key, persist_key, bridge
 from checkov.common.bridgecrew.wrapper import reduce_scan_reports, persist_checks_results, \
     enrich_and_persist_checks_metadata
 from checkov.common.models.consts import SUPPORTED_FILE_EXTENSIONS
+from checkov.common.runners.base_runner import filter_ignored_paths
 from checkov.version import version as checkov_version
 
 EMAIL_PATTERN = r"[^@]+@[^@]+\.[^@]+"
@@ -52,10 +54,11 @@ class BcPlatformIntegration(object):
         self.repo_branch = None
         self.skip_fixes = False
         self.skip_suppressions = False
+        self.skip_policy_download = False
         self.timestamp = None
         self.scan_reports = []
         self.bc_api_url = os.getenv('BC_API_URL', "https://www.bridgecrew.cloud/api/v1")
-        self.bc_source = os.getenv('BC_SOURCE', 'cli')
+        self.bc_source = None
         self.bc_source_version = None
         self.integrations_api_url = f"{self.bc_api_url}/integrations/types/checkov"
         self.guidelines_api_url = f"{self.bc_api_url}/guidelines"
@@ -69,6 +72,7 @@ class BcPlatformIntegration(object):
         self.use_s3_integration = False
         self.platform_integration_configured = False
         self.http = None
+        self.excluded_paths = []
 
     def setup_http_manager(self, ca_certificate=os.getenv('BC_CA_BUNDLE', None)):
         """
@@ -89,10 +93,11 @@ class BcPlatformIntegration(object):
             except KeyError:
                 self.http = urllib3.PoolManager()
 
-    def setup_bridgecrew_credentials(self, bc_api_key, repo_id, skip_fixes=False, skip_suppressions=False, source=None,
-                                     source_version=None, repo_branch=None):
+    def setup_bridgecrew_credentials(self, bc_api_key, repo_id, skip_fixes=False, skip_suppressions=False,
+                                     skip_policy_download=False, source=None, source_version=None, repo_branch=None):
         """
         Setup credentials against Bridgecrew's platform.
+        :param source:
         :param skip_fixes: whether to skip querying fixes from Bridgecrew
         :param repo_id: Identity string of the scanned repository, of the form <repo_owner>/<repo_name>
         :param bc_api_key: Bridgecrew issued API key
@@ -102,12 +107,11 @@ class BcPlatformIntegration(object):
         self.repo_branch = repo_branch
         self.skip_fixes = skip_fixes
         self.skip_suppressions = skip_suppressions
-        if source:
-            self.bc_source = source
-        if source_version:
-            self.bc_source_version = source_version
+        self.skip_policy_download = skip_policy_download
+        self.bc_source = source
+        self.bc_source_version = source_version
 
-        if self.bc_source != 'vscode':
+        if self.bc_source.upload_results:
             try:
                 self.skip_fixes = True  # no need to run fixes on CI integration
                 repo_full_path, response = self.get_s3_role(bc_api_key, repo_id)
@@ -160,22 +164,34 @@ class BcPlatformIntegration(object):
         """
         return self.platform_integration_configured
 
-    def persist_repository(self, root_dir):
+    def persist_repository(self, root_dir, files=None, excluded_paths=[]):
         """
-        Persist the repository found on root_dir path to Bridgecrew's platform
-        :param root_dir: Absolute path of the directory containing the repository root level
+        Persist the repository found on root_dir path to Bridgecrew's platform. If --file flag is used, only files
+        that are specified will be persisted.
+        :param files: Absolute path of the files passed in the --file flag.
+        :param root_dir: Absolute path of the directory containing the repository root level.
         """
 
         if not self.use_s3_integration:
             return
 
-        for root_path, d_names, f_names in os.walk(root_dir):
-            for file_path in f_names:
-                _, file_extension = os.path.splitext(file_path)
+        if files:
+            for f in files:
+                _, file_extension = os.path.splitext(f)
                 if file_extension in SUPPORTED_FILE_EXTENSIONS:
-                    full_file_path = os.path.join(root_path, file_path)
-                    relative_file_path = os.path.relpath(full_file_path, root_dir)
-                    self._persist_file(full_file_path, relative_file_path)
+                    self._persist_file(f, os.path.relpath(f, root_dir))
+        else:
+            for root_path, d_names, f_names in os.walk(root_dir):
+                # self.excluded_paths only contains the config fetched from the platform.
+                # but here we expect the list from runner_registry as well (which includes self.excluded_paths).
+                filter_ignored_paths(root_path, d_names, excluded_paths)
+                filter_ignored_paths(root_path, f_names, excluded_paths)
+                for file_path in f_names:
+                    _, file_extension = os.path.splitext(file_path)
+                    if file_extension in SUPPORTED_FILE_EXTENSIONS:
+                        full_file_path = os.path.join(root_path, file_path)
+                        relative_file_path = os.path.relpath(full_file_path, root_dir)
+                        self._persist_file(full_file_path, relative_file_path)
 
     def persist_scan_results(self, scan_reports):
         """
@@ -203,7 +219,7 @@ class BcPlatformIntegration(object):
         request = None
         try:
 
-            request = self.http.request("PUT", f"{self.integrations_api_url}?source={self.bc_source}",
+            request = self.http.request("PUT", f"{self.integrations_api_url}?source={self.bc_source.name}",
                                    body=json.dumps({"path": self.repo_path, "branch": branch, "to_branch": BC_TO_BRANCH,
                                                     "pr_id": BC_PR_ID, "pr_url": BC_PR_URL,
                                                     "commit_hash": BC_COMMIT_HASH, "commit_url": BC_COMMIT_URL,
@@ -211,7 +227,7 @@ class BcPlatformIntegration(object):
                                                     "run_id": BC_RUN_ID, "run_url": BC_RUN_URL,
                                                     "repository_url": BC_REPOSITORY_URL}),
                                    headers={"Authorization": self.bc_api_key, "Content-Type": "application/json",
-                                            'x-api-client': self.bc_source, 'x-api-checkov-version': checkov_version
+                                            'x-api-client': self.bc_source.name, 'x-api-checkov-version': checkov_version
                                             })
             response = json.loads(request.data.decode("utf8"))
             url = response.get("url", None)
@@ -267,7 +283,7 @@ class BcPlatformIntegration(object):
 
     def get_checkov_mapping_metadata(self) -> dict:
         BC_SKIP_MAPPING = os.getenv("BC_SKIP_MAPPING","FALSE")
-        if BC_SKIP_MAPPING == "TRUE":
+        if BC_SKIP_MAPPING.upper() == "TRUE":
             logging.debug(f"Skipped mapping API call")
             return {}
         try:
@@ -283,28 +299,54 @@ class BcPlatformIntegration(object):
 
     def onboarding(self):
         if not self.bc_api_key:
-            print(Style.BRIGHT + colored("Visualize and collaborate on security issues with Bridgecrew! \n", 'blue',
-                                         attrs=['bold']) + colored(
-                "Bridgecrew's dashboard allows automation of future checks, Pull Request scanning and "
-                "auto-comments, automatic remidiation PR's and more! \n Plus it's free for 100 cloud resources and a "
-                "great way to visualize and collaborate on Checkov results. For more information on dashboard integration, see: http://bridge.dev/checkov-dashboard \n \n To instantly see future Checkov scans in the "
-                "platform, Press y! \n",
-                'yellow') + Style.RESET_ALL)
-            reply = self._input_visualize_results()
+            print(Style.BRIGHT + colored("\nWould you like to “level up” your Checkov powers for free?  The upgrade includes: \n\n", 'green',
+                                         attrs=['bold'])  + colored(
+                u"\u2022 " + "Command line docker Image scanning\n"
+                u"\u2022 " + "Free (forever) bridgecrew.cloud account with API access\n"
+                u"\u2022 " + "Auto-fix remediation suggestions\n"
+                u"\u2022 " + "Enabling of VS Code Plugin\n"
+                u"\u2022 " + "Dashboard visualisation of Checkov scans\n"
+                u"\u2022 " + "Integration with GitHub for:\n"
+                "\t" + u"\u25E6 " + "\tAutomated Pull Request scanning\n"
+                "\t" + u"\u25E6 " + "\tAuto remediation PR generation\n"
+                u"\u2022 " + "Integration with up to 100 cloud resources for:\n"
+                "\t" + u"\u25E6 " + "\tAutomated cloud resource checks\n"
+                "\t" + u"\u25E6 " + "\tResource drift detection\n"
+                "\n"           
+                "\n" + "and much more...",'yellow') + 
+                colored("\n\nIt's easy and only takes 2 minutes. We can do it right now!\n\n"
+                "To Level-up, press 'y'... \n",
+                'cyan') + Style.RESET_ALL)
+            reply = self._input_levelup_results()
             if reply[:1] == 'y':
-                print(Style.BRIGHT + colored("\nEmail Address? \n", 'blue', attrs=['bold']))
+                print(Style.BRIGHT + colored("\nOk, let’s get you started on creating your free account! \n"
+                "\nEnter your email address to begin: ",'green', attrs=['bold']) + colored(" // This will be used as your login at https://bridgecrew.cloud.\n", 'green'))
                 if not self.bc_api_key:
                     email = self._input_email()
+                    print(Style.BRIGHT + colored("\nLooks good!"
+                    "\nNow choose an Organisation Name: ",'green', attrs=['bold']) + colored(" // This will enable collaboration with others who you can add to your team.\n", 'green'))
                     org = self._input_orgname()
-
+                    print(Style.BRIGHT + colored("\nAmazing!"
+                    "\nWe are now generating a personal API key to immediately enable some new features… ",'green', attrs=['bold']))
+ 
                     bc_api_token, response = self.get_api_token(email, org)
                     self.bc_api_key = bc_api_token
                     if response.status_code == 200:
-                        print('\n Saving API key to {}'.format(bridgecrew_file))
-                        print(Style.BRIGHT + colored(
-                            "\n Checkov Dashboard configured, opening https://bridgecrew.cloud, check your inbox for login details! \n",
-                            'blue', attrs=['bold']))
+                        print(Style.BRIGHT + colored("\nComplete!",'green', attrs=['bold']))
+                        print('\nSaving API key to {}'.format(bridgecrew_file))
+                        print(Style.BRIGHT + colored("\nCheckov will automatically check this location for a key.  If you forget it you’ll find it here\nhttps://bridgecrew.cloud/integrations/api-token\n\n",'green'))
                         persist_key(self.bc_api_key)
+                        print(Style.BRIGHT + colored("Checkov Dashboard is configured, opening https://bridgecrew.cloud to explore your new powers.", 'green', attrs=['bold']))
+                        print(Style.BRIGHT + colored("FYI - check your inbox for login details! \n", 'green'))
+
+                        print(Style.BRIGHT + colored("Congratulations! You’ve just super-sized your Checkov!  Why not test-drive image scanning now:",'cyan')) 
+
+                        print(Style.BRIGHT + colored("\ncheckov --docker-image ubuntu --dockerfile-path /Users/bob/workspaces/bridgecrew/Dockerfile --repo-id bob/test --branch master\n",'white'))
+
+                        print(Style.BRIGHT + colored("Or download our VS Code plugin:  https://github.com/bridgecrewio/checkov-vscode \n", 'cyan',attrs=['bold']))                  
+
+                        print(Style.BRIGHT + colored( "Interested in contributing to Checkov as an open source developer.  We thought you’d never ask.  Check us out at: \nhttps://github.com/bridgecrewio/checkov/issues?q=is%3Aopen+is%3Aissue+label%3A%22good+first+issue%22 \n", 'white', attrs=['bold']))   
+                       
                     else:
                         print(
                             Style.BRIGHT + colored("\nCould not create account, please try again on your next scan! \n",
@@ -326,6 +368,34 @@ class BcPlatformIntegration(object):
             if self.is_integration_configured():
                 self._upload_run(args, scan_reports)
 
+# Added this to generate a default repo_id for cli scans for upload to the platform 
+# whilst also persisting a cli repo_id into the object
+    def persist_bc_api_key(self, args):
+        if args.bc_api_key:
+            self.bc_api_key=args.bc_api_key
+        else: 
+            # get the key from file
+            self.bc_api_key=read_key()
+        return self.bc_api_key    
+
+# Added this to generate a default repo_id for cli scans for upload to the platform 
+# whilst also persisting a cli repo_id into the object
+    def persist_repo_id(self, args):
+        if args.repo_id is None:
+            if BC_FROM_BRANCH:
+                self.repo_id = BC_FROM_BRANCH
+            if args.directory:
+                basename = path.basename(os.path.abspath(args.directory[0]))
+                self.repo_id = "cli_repo/" + basename
+            if args.file:
+                # Get the base path of the file based on it's absolute path
+                basename = os.path.basename(os.path.dirname(os.path.abspath(args.file[0])))
+                self.repo_id = "cli_repo/" + basename
+ 
+        else: 
+            self.repo_id=args.repo_id
+        return self.repo_id    
+
     def get_repository(self, args):
         if BC_FROM_BRANCH:
             return BC_FROM_BRANCH
@@ -339,7 +409,7 @@ class BcPlatformIntegration(object):
         return bc_api_token, response
 
     def _upload_run(self, args, scan_reports):
-        print(Style.BRIGHT + colored("Sucessfully configured Bridgecrew.cloud...", 'green',
+        print(Style.BRIGHT + colored("Connecting to Bridgecrew.cloud...", 'green',
                                      attrs=['bold']) + Style.RESET_ALL)
         self.persist_repository(args.directory[0])
         print(Style.BRIGHT + colored("Metadata upload complete", 'green',
@@ -349,8 +419,7 @@ class BcPlatformIntegration(object):
                                      attrs=['bold']) + Style.RESET_ALL)
         self.commit_repository(args.branch)
         print(Style.BRIGHT + colored(
-            "COMPLETE! Your Bridgecrew dashboard is available here: https://bridgecrew.cloud \n"
-            "Login information should be in your email inbox", 'green', attrs=['bold']) + Style.RESET_ALL)
+            "COMPLETE! \nYour results are in your Bridgecrew dashboard, available here: https://bridgecrew.cloud \n", 'green', attrs=['bold']) + Style.RESET_ALL)
 
     def _create_bridgecrew_account(self, email, org):
         """
@@ -377,7 +446,7 @@ class BcPlatformIntegration(object):
         while not valid:
             result = str(
                 input(
-                    'Organization name (this will create an account with matching identifier): ')).lower().strip()  # nosec
+                    'Organization name: ')).lower().strip()  # nosec
             # remove spaces and special characters
             result = ''.join(e for e in result if e.isalnum())
             if result:
@@ -393,10 +462,19 @@ class BcPlatformIntegration(object):
                 valid = True
         return result
 
+    def _input_levelup_results(self):
+        valid = False
+        result = None
+        while not valid:
+            result = str(input('Level up? (y/n): ')).lower().strip()  # nosec
+            if result[:1] in ["y", "n"]:
+                valid = True
+        return result
+
     def _input_email(self):
         valid_email = False
         while not valid_email:
-            email = str(input('E-Mail:')).lower().strip()  # nosec
+            email = str(input('E-Mail: ')).lower().strip()  # nosec
             if re.search(EMAIL_PATTERN, email):
                 valid_email = True
             else:
@@ -411,5 +489,23 @@ class BcPlatformIntegration(object):
                 t.set_postfix(refresh=False)
                 sleep(1)
 
+    def get_excluded_paths(self):
+        repo_settings_api_url = f'{self.bc_api_url}/vcs/settings/scheme'
+        try:
+            request = self.http.request("GET", repo_settings_api_url,
+                                        headers={"Authorization": self.bc_api_key, "Content-Type": "application/json"})
+            response = json.loads(request.data.decode("utf8"))
+            if 'scannedFiles' in response:
+                for section in response.get('scannedFiles').get('sections'):
+                    if self.repo_id in section.get('repos') and section.get('rule').get('excludePaths'):
+                        self.excluded_paths.extend(section.get('rule').get('excludePaths'))
+            return self.excluded_paths
+        except HTTPError as e:
+            logging.error(f"Failed to get vcs settings for repo {self.repo_path}\n{e}")
+            raise e
+        except JSONDecodeError as e:
+            logging.error(f"Response of {repo_settings_api_url} is not a valid JSON\n{e}")
+            raise e
+
 
 bc_integration = BcPlatformIntegration()
