@@ -26,7 +26,7 @@ class Record:
 
     def __init__(self, check_id, check_name, check_result, code_block, file_path, file_line_range, resource,
                  evaluations, check_class, file_abs_path, entity_tags=None,
-                 caller_file_path=None, caller_file_line_range=None):
+                 caller_file_path=None, caller_file_line_range=None, bc_check_id=None):
         """
         :param evaluations: A dict with the key being the variable name, value being a dict containing:
                              - 'var_file'
@@ -34,6 +34,7 @@ class Record:
                              - 'definitions', a list of dicts which contain 'definition_expression'
         """
         self.check_id = check_id
+        self.bc_check_id = bc_check_id
         self.check_name = check_name
         self.check_result = check_result
         self.code_block = code_block
@@ -73,7 +74,7 @@ class Record:
                 string_block += "\t\t" + Fore.WHITE + str(line_num) + spaces + ' | ' + Fore.YELLOW + line
         return string_block
 
-    def to_string(self, compact=False):
+    def to_string(self, compact=False, use_bc_ids=False):
         status = ''
         evaluation_message = f''
         status_color = "white"
@@ -88,7 +89,7 @@ class Record:
             status_color = 'blue'
             suppress_comment = "\tSuppress comment: {}\n".format(self.check_result['suppress_comment'])
 
-        check_message = colored("Check: {}: \"{}\"\n".format(self.check_id, self.check_name), "white")
+        check_message = colored("Check: {}: \"{}\"\n".format(self.get_output_id(use_bc_ids), self.check_name), "white")
         guideline_message = ''
         if self.guideline:
             guideline_message = "\tGuide: " + Style.BRIGHT + colored(f"{self.guideline}\n", 'blue', attrs=['underline']) + Style.RESET_ALL
@@ -127,3 +128,6 @@ class Record:
 
     def __str__(self):
         return self.to_string()
+
+    def get_output_id(self, use_bc_ids: bool) -> str:
+        return self.bc_check_id if self.bc_check_id and use_bc_ids else self.check_id
