@@ -3,10 +3,6 @@ from checkov.common.models.enums import CheckResult
 
 
 class Registry(BaseCheckRegistry):
-    def __init__(self):
-        super().__init__()
-
-
     def scan(self, scanned_file, entity, skipped_checks, runner_filter):
 
         results = {}
@@ -20,7 +16,7 @@ class Registry(BaseCheckRegistry):
                     if check.id in [x['id'] for x in skipped_checks]:
                         skip_info = [x for x in skipped_checks if x['id'] == check.id][0]
 
-                    if runner_filter.should_run_check(check.id):
+                    if runner_filter.should_run_check(check.id, check.bc_id):
                         entity_name = instruction
                         entity_type = instruction
                         entity_configuration = entity[instruction]
@@ -32,7 +28,7 @@ class Registry(BaseCheckRegistry):
                 if check.id in [x['id'] for x in skipped_checks]:
                     skip_info = [x for x in skipped_checks if x['id'] == check.id][0]
 
-            if runner_filter.should_run_check(check.id):
+            if runner_filter.should_run_check(check.id, check.bc_id):
                 entity_name = scanned_file
                 entity_type = "*"
                 entity_configuration = entity
