@@ -19,7 +19,7 @@ class AllowPrivilegeEscalation(BaseK8Check):
         super().__init__(name=name, id=id, categories=categories, supported_entities=supported_kind)
 
     def get_resource_id(self, conf):
-        return f'{conf["parent"]} - {conf["name"]}'
+        return f'{conf["parent"]} - {conf["name"]}' if conf.get('name') else conf["parent"]
 
     def scan_spec_conf(self, conf):
         if "securityContext" in conf:
