@@ -1,6 +1,7 @@
 
 from checkov.common.models.enums import CheckCategories, CheckResult
 from checkov.kubernetes.base_spec_check import BaseK8Check
+from checkov.kubernetes.checks.k8s_check_utils import extract_commands
 
 
 class ApiServerEncryptionProviders(BaseK8Check):
@@ -12,21 +13,11 @@ class ApiServerEncryptionProviders(BaseK8Check):
         super().__init__(name=name, id=id, categories=categories, supported_entities=supported_entities)
 
     def get_resource_id(self, conf):
-        return f'{conf["parent"]} - {conf["name"]}'
+        return f'{conf["parent"]} - {conf["name"]}' if conf.get('name') else conf["parent"]
 
     def scan_spec_conf(self, conf):
-        keys=[]
-        values=[]
-        if "command" in conf:
-            for cmd in conf["command"]:
-                if "=" in cmd:
-                    firstEqual = cmd.index("=")
-                    [key, value] = [cmd[:firstEqual], cmd[firstEqual+1:]]
-                    keys.append(key)
-                    values.append(value)
-                else:
-                    keys.append(cmd)
-                    values.append(None)
+        keys, values = extract_commands(conf)
+
         if "kube-apiserver" in keys:
             if "--encryption-provider-config" not in keys:
                         return CheckResult.FAILED
