@@ -2,6 +2,7 @@ import dpath
 
 from checkov.common.models.enums import CheckCategories, CheckResult
 from checkov.kubernetes.base_spec_check import BaseK8Check
+from checkov.common.util.type_forcers import force_list
 
 
 class Seccomp(BaseK8Check):
@@ -56,14 +57,12 @@ class Seccomp(BaseK8Check):
                             if "metadata" in conf["spec"]["jobTemplate"]["spec"]["template"]:
                                 metadata = conf["spec"]["jobTemplate"]["spec"]["template"]["metadata"]
         else:
-            if "spec" in conf:
-                if "template" in conf["spec"]:
-                    if "metadata" in conf["spec"]["template"]:
-                        metadata = conf["spec"]["template"]["metadata"]
+            inner_metadata = self.get_inner_entry(conf, "metadata")
+            metadata = inner_metadata if inner_metadata else metadata
 
         if metadata:
-            if "annotations" in metadata:
-                for annotation in metadata["annotations"]:
+            if metadata.get('annotations'):
+                for annotation in force_list(metadata["annotations"]):
                     for key in annotation:
                         if "seccomp.security.alpha.kubernetes.io/pod" in key:
                             if "docker/default" in annotation[key] or "runtime/default" in annotation[key]:
