@@ -13,7 +13,7 @@ class Tiller(BaseK8Check):
         super().__init__(name=name, id=id, categories=categories, supported_entities=supported_kind)
 
     def get_resource_id(self, conf):
-        return f'{conf["parent"]} - {conf["name"]}'
+        return f'{conf["parent"]} - {conf["name"]}' if conf.get('name') else conf["parent"]
 
     def scan_spec_conf(self, conf):
         return CheckResult.FAILED if self.is_tiller(conf) else CheckResult.PASSED
@@ -25,12 +25,12 @@ class Tiller(BaseK8Check):
             if isinstance(conf_image,str) and  "tiller" in conf_image:
                     return True
 
-        if "parent_metadata" in conf:
-            if "labels" in conf["parent_metadata"]:
-                if "app" in conf["parent_metadata"]["labels"]:
+        if conf["parent_metadata"]:
+            if conf["parent_metadata"].get("labels"):
+                if conf["parent_metadata"]["labels"].get("app"):
                     if conf["parent_metadata"]["labels"]["app"] == "helm":
                         return True
-                elif "name" in conf["parent_metadata"]["labels"]:
+                elif conf["parent_metadata"]["labels"].get("name"):
                     if conf["parent_metadata"]["labels"]["name"] == "tiller":
                         return True
 
