@@ -2,10 +2,12 @@ import logging
 import operator
 import os
 from functools import reduce
+
+from checkov.common.bridgecrew.platform_integration import bc_integration
 from checkov.common.util.type_forcers import force_list
 from checkov.common.output.record import Record
 from checkov.common.output.report import Report
-from checkov.common.runners.base_runner import BaseRunner, filter_ignored_directories
+from checkov.common.runners.base_runner import BaseRunner, filter_ignored_paths
 from checkov.kubernetes.parser.parser import parse
 from checkov.kubernetes.registry import registry
 from checkov.runner_filter import RunnerFilter
@@ -34,7 +36,8 @@ class Runner(BaseRunner):
 
         if root_folder:
             for root, d_names, f_names in os.walk(root_folder):
-                filter_ignored_directories(d_names)
+                filter_ignored_paths(root, d_names, runner_filter.excluded_paths)
+                filter_ignored_paths(root, f_names, runner_filter.excluded_paths)
 
                 for file in f_names:
                     file_ending = os.path.splitext(file)[1]
@@ -178,7 +181,7 @@ class Runner(BaseRunner):
                     variable_evaluations = {}
 
                     for check, check_result in results.items():
-                        record = Record(check_id=check.id, check_name=check.name, check_result=check_result,
+                        record = Record(check_id=check.id, bc_check_id=check.bc_id, check_name=check.name, check_result=check_result,
                                         code_block=entity_code_lines, file_path=k8_file,
                                         file_line_range=entity_lines_range,
                                         resource=check.get_resource_id(entity_conf), evaluations=variable_evaluations,
@@ -220,6 +223,8 @@ class Runner(BaseRunner):
 def get_skipped_checks(entity_conf):
     skipped = []
     metadata = {}
+    bc_id_mapping = bc_integration.get_id_mapping()
+    ckv_to_bc_id_mapping = bc_integration.get_ckv_to_bc_id_mapping()
     if not isinstance(entity_conf,dict):
         return skipped
     if entity_conf["kind"] == "containers" or entity_conf["kind"] == "initContainers":
@@ -237,12 +242,19 @@ def get_skipped_checks(entity_conf):
             for key in annotation:
                 skipped_item = {}
                 if "checkov.io/skip" in key or "bridgecrew.io/skip" in key:
-                    if "CKV_K8S" in annotation[key]:
+                    if "CKV_K8S" in annotation[key] or "BC_K8S" in annotation[key]:
                         if "=" in annotation[key]:
                             (skipped_item["id"], skipped_item["suppress_comment"]) = annotation[key].split("=")
                         else:
                             skipped_item["id"] = annotation[key]
                             skipped_item["suppress_comment"] = "No comment provided"
+
+                        # No matter which ID was used to skip, save the pair of IDs in the appropriate fields
+                        if bc_id_mapping and skipped_item["id"] in bc_id_mapping:
+                            skipped_item["bc_id"] = skipped_item["id"]
+                            skipped_item["id"] = bc_id_mapping[skipped_item["id"]]
+                        elif ckv_to_bc_id_mapping:
+                            skipped_item["bc_id"] = ckv_to_bc_id_mapping.get(skipped_item["id"])
                         skipped.append(skipped_item)
                     else:
                         logging.debug("Parse of Annotation Failed for {}: {}".format(metadata["annotations"][key], entity_conf, indent=2))
