@@ -7,12 +7,11 @@ import os
 def init():
     LOG_LEVEL = os.environ.get('LOG_LEVEL', 'WARNING').upper()
     logging.basicConfig(level=LOG_LEVEL)
-    logFormatter = logging.Formatter("%(asctime)s [%(threadName)-12.12s] [%(levelname)-5.5s]  %(message)s")
-    rootLogger = logging.getLogger()
-    consoleHandler = logging.StreamHandler(sys.stderr)
-    consoleHandler.setFormatter(logFormatter)
-    consoleHandler.setLevel(LOG_LEVEL)
-    rootLogger.addHandler(consoleHandler)
+    log_formatter = logging.Formatter("%(asctime)s [%(threadName)-12.12s] [%(levelname)-5.5s]  %(message)s")
+    root_logger = logging.getLogger()
+    stream_handler = root_logger.handlers[0]
+    stream_handler.setFormatter(log_formatter)
+    root_logger.setLevel(LOG_LEVEL)
     logging.getLogger().setLevel(LOG_LEVEL)
     logging.getLogger("urllib3").setLevel(logging.ERROR)
     logging.getLogger("urllib3.connectionpool").setLevel(logging.ERROR)
