@@ -3,6 +3,7 @@ import fnmatch
 from typing import Set, Optional, Union, List
 
 from checkov.common.util.consts import DEFAULT_EXTERNAL_MODULES_DIR
+from checkov.common.util.type_forcers import convert_csv_string_arg_to_list
 
 
 class RunnerFilter(object):
@@ -21,20 +22,12 @@ class RunnerFilter(object):
         evaluate_variables: bool = True,
         runners: Optional[List[str]] = None,
         skip_framework: Optional[str] = None,
+        excluded_paths: Optional[List[str]] = None,
+        all_external: bool = False
     ) -> None:
-        if checks is None:
-            checks = []
-        if isinstance(checks, str):
-            self.checks = checks.split(",")
-        else:
-            self.checks = checks
 
-        if skip_checks is None:
-            skip_checks = []
-        if isinstance(skip_checks, str):
-            self.skip_checks = skip_checks.split(",")
-        else:
-            self.skip_checks = skip_checks
+        self.checks = convert_csv_string_arg_to_list(checks)
+        self.skip_checks = convert_csv_string_arg_to_list(skip_checks)
 
         if skip_framework is None:
             self.framework = framework
@@ -54,16 +47,18 @@ class RunnerFilter(object):
         self.download_external_modules = download_external_modules
         self.external_modules_download_path = external_modules_download_path
         self.evaluate_variables = evaluate_variables
+        self.excluded_paths = excluded_paths
+        self.all_external = all_external
 
-    def should_run_check(self, check_id: str) -> bool:
-        if RunnerFilter.is_external_check(check_id):
+    def should_run_check(self, check_id: str, bc_check_id: Optional[str] = None) -> bool:
+        if RunnerFilter.is_external_check(check_id) and self.all_external:
             pass  # enabled unless skipped
         elif self.checks:
-            if check_id in self.checks:
+            if check_id in self.checks or bc_check_id in self.checks:
                 return True
             else:
                 return False
-        if self.skip_checks and any(fnmatch.fnmatch(check_id, pattern) for pattern in self.skip_checks):
+        if self.skip_checks and any((fnmatch.fnmatch(check_id, pattern) or (bc_check_id and fnmatch.fnmatch(bc_check_id, pattern))) for pattern in self.skip_checks):
             return False
         return True
 
