@@ -1,8 +1,9 @@
-from checkov.terraform.models.enums import CheckResult, CheckCategories
-from checkov.terraform.checks.resource.base_check import BaseResourceCheck
-
 import json
 
+from checkov.common.models.enums import CheckResult, CheckCategories
+from checkov.common.util.type_forcers import is_json
+from checkov.terraform.checks.resource.base_resource_check import BaseResourceCheck
+
 
 class ECRPolicy(BaseResourceCheck):
     def __init__(self):
@@ -20,8 +21,9 @@ class ECRPolicy(BaseResourceCheck):
         :return: <CheckResult>
         """
         if "policy" in conf.keys():
-            if json.loads(conf["policy"][0])['Statement'][0]['Principal'] == '*':
-                return CheckResult.FAILED
+            if is_json(conf["policy"][0]):
+                if json.loads(conf["policy"][0])['Statement'][0]['Principal'] == '*':
+                    return CheckResult.FAILED
         return CheckResult.PASSED
 
 
