@@ -1,8 +1,9 @@
-from checkov.common.models.enums import CheckResult, CheckCategories
-from checkov.terraform.checks.resource.base_resource_check import BaseResourceCheck
-import json
 import re
 
+from checkov.common.models.enums import CheckResult, CheckCategories
+from checkov.common.util.type_forcers import extract_policy_dict
+from checkov.terraform.checks.resource.base_resource_check import BaseResourceCheck
+
 
 class IAMRoleAllowAssumeFromAccount(BaseResourceCheck):
 
@@ -16,14 +17,14 @@ class IAMRoleAllowAssumeFromAccount(BaseResourceCheck):
     def scan_resource_conf(self, conf):
         if conf.get('assume_role_policy') and isinstance(conf['assume_role_policy'][0], str):
             try:
-                assume_role_block = json.loads(conf['assume_role_policy'][0])
-                if 'Statement' in assume_role_block.keys():
+                assume_role_block = extract_policy_dict(conf['assume_role_policy'][0])
+                if assume_role_block and 'Statement' in assume_role_block.keys():
                     if 'Principal' in assume_role_block['Statement'][0]:
                         if 'AWS' in assume_role_block['Statement'][0]['Principal']:
                             account_access = re.compile(r'\d{12}|arn:aws:iam::\d{12}:root')
                             if re.match(account_access, assume_role_block['Statement'][0]['Principal']['AWS']):
                                 return CheckResult.FAILED
-            except: # nosec
+            except:  # nosec
                 pass
         return CheckResult.PASSED
 
