@@ -1,6 +1,6 @@
 from checkov.common.models.enums import CheckResult, CheckCategories
+from checkov.common.util.type_forcers import extract_policy_dict
 from checkov.terraform.checks.resource.base_resource_check import BaseResourceCheck
-import json
 
 
 class IAMRoleAllowsPublicAssume(BaseResourceCheck):
@@ -13,10 +13,10 @@ class IAMRoleAllowsPublicAssume(BaseResourceCheck):
         super().__init__(name=name, id=id, categories=categories, supported_resources=supported_resources)
 
     def scan_resource_conf(self, conf):
-        if isinstance(conf['assume_role_policy'][0], str):
+        if conf.get('assume_role_policy'):
             try:
-                assume_role_block = json.loads(conf['assume_role_policy'][0])
-                if 'Statement' in assume_role_block.keys():
+                assume_role_block = extract_policy_dict(conf['assume_role_policy'][0])
+                if assume_role_block and 'Statement' in assume_role_block.keys():
                     for statement in assume_role_block['Statement']:
                         if 'Effect' in statement and statement['Effect'] == 'Deny':
                             continue
@@ -25,7 +25,7 @@ class IAMRoleAllowsPublicAssume(BaseResourceCheck):
                             aws = statement['Principal']['AWS']
                             if (type(aws) == str and aws == '*') or (type(aws) == list and '*' in aws):
                                 return CheckResult.FAILED
-            except: # nosec
+            except:  # nosec
                 pass
         return CheckResult.PASSED
 
