@@ -3,8 +3,8 @@ from checkov.terraform.checks.resource.base_resource_value_check import BaseReso
 from checkov.common.util.type_forcers import force_list
 import re
 
-INTERNET_ADDRESSES = ["*", "0.0.0.0", "<nw>/0", "/0", "internet", "any"]
-PORT_RANGE = re.compile('\d+-\d+')
+INTERNET_ADDRESSES = ["*", "0.0.0.0", "<nw>/0", "/0", "internet", "any"] # nosec
+PORT_RANGE = re.compile(r'\d+-\d+')
 
 
 class NSGRulePortAccessRestricted(BaseResourceCheck):
