@@ -4,13 +4,16 @@ import logging
 import os
 import re
 from copy import deepcopy
+import datetime
 from pathlib import Path
 from typing import Optional, Dict, Mapping, Set, Tuple, Callable, Any, List
+from json import dumps, loads, JSONEncoder
 
 import deep_merge
 import hcl2
+from lark import Tree
 
-from checkov.common.runners.base_runner import filter_ignored_directories
+from checkov.common.runners.base_runner import filter_ignored_paths
 from checkov.common.util.consts import DEFAULT_EXTERNAL_MODULES_DIR, RESOLVED_MODULE_ENTRY_NAME
 from checkov.common.variables.context import EvaluationContext
 from checkov.terraform.checks.utils.dependency_path_handler import unify_dependency_path
@@ -24,9 +27,20 @@ from checkov.terraform.parser_utils import eval_string, find_var_blocks
 external_modules_download_path = os.environ.get('EXTERNAL_MODULES_DIR', DEFAULT_EXTERNAL_MODULES_DIR)
 
 
-def _filter_ignored_directories(d_names):
-    filter_ignored_directories(d_names)
-    [d_names.remove(d) for d in list(d_names) if d in [default_ml_registry.external_modules_folder_name]]
+class DefinitionsEncoder(JSONEncoder):
+    def default(self, obj):
+        if isinstance(obj, set):
+            return list(obj)
+        elif isinstance(obj, Tree):
+            return str(obj)
+        elif isinstance(obj, datetime.date):
+            return str(obj)
+        return super().default(obj)
+
+
+def _filter_ignored_paths(root, paths, excluded_paths):
+    filter_ignored_paths(root, paths, excluded_paths)
+    [paths.remove(path) for path in list(paths) if path in [default_ml_registry.external_modules_folder_name]]
 
 
 class Parser:
@@ -44,7 +58,8 @@ class Parser:
               out_parsing_errors: Dict[str, Exception],
               env_vars: Mapping[str, str],
               download_external_modules: bool,
-              external_modules_download_path: str):
+              external_modules_download_path: str,
+              excluded_paths: Optional[List[str]] = None):
         self.directory = directory
         self.out_definitions = out_definitions
         self.out_evaluations_context = out_evaluations_context
@@ -59,6 +74,7 @@ class Parser:
             self.out_parsing_errors = {}
         if self.env_vars is None:
             self.env_vars = dict(os.environ)
+        self.excluded_paths = excluded_paths
 
     def _check_process_dir(self, directory):
         if directory not in self._parsed_directories:
@@ -72,13 +88,13 @@ class Parser:
                         out_parsing_errors: Dict[str, Exception] = None,
                         env_vars: Mapping[str, str] = None,
                         download_external_modules: bool = False,
-                        external_modules_download_path: str = DEFAULT_EXTERNAL_MODULES_DIR):
+                        external_modules_download_path: str = DEFAULT_EXTERNAL_MODULES_DIR,
+                        excluded_paths: Optional[List[str]] = None):
         self._init(directory, out_definitions, out_evaluations_context, out_parsing_errors, env_vars,
-                   download_external_modules, external_modules_download_path)
+                   download_external_modules, external_modules_download_path, excluded_paths)
         self._parsed_directories.clear()
         default_ml_registry.download_external_modules = download_external_modules
         default_ml_registry.external_modules_folder_name = external_modules_download_path
-
         self._parse_directory(dir_filter=lambda d: self._check_process_dir(d))
 
     @staticmethod
@@ -118,7 +134,8 @@ class Parser:
 
         if include_sub_dirs:
             for sub_dir, d_names, f_names in os.walk(self.directory):
-                _filter_ignored_directories(d_names)
+                _filter_ignored_paths(sub_dir, d_names, self.excluded_paths)
+                _filter_ignored_paths(sub_dir, f_names, self.excluded_paths)
                 if dir_filter(os.path.abspath(sub_dir)):
                     self._internal_dir_load(sub_dir, module_loader_registry, dir_filter,
                                             keys_referenced_as_modules)
@@ -419,16 +436,17 @@ class Parser:
             deep_merge.merge(self.out_evaluations_context, all_module_evaluations_context)
         return skipped_a_module
 
-    def parse_hcl_module(self, source_dir, source, download_external_modules=False, parsing_errors=None):
+    def parse_hcl_module(self, source_dir, source, download_external_modules=False, parsing_errors=None, excluded_paths: List[str]=None):
         tf_definitions = {}
         self.parse_directory(directory=source_dir, out_definitions=tf_definitions, out_evaluations_context={},
                              out_parsing_errors=parsing_errors if parsing_errors is not None else {},
                              download_external_modules=download_external_modules,
-                             external_modules_download_path=external_modules_download_path)
-        tf_definitions = Parser._hcl_boolean_types_to_boolean(tf_definitions)
+                             external_modules_download_path=external_modules_download_path, excluded_paths=excluded_paths)
+        tf_definitions = self._clean_parser_types(tf_definitions)
+        tf_definitions = self._serialize_definitions(tf_definitions)
         return self.parse_hcl_module_from_tf_definitions(tf_definitions, source_dir, source)
 
-    def parse_hcl_module_from_tf_definitions(self, tf_definitions, source_dir, source):
+    def parse_hcl_module_from_tf_definitions(self, tf_definitions, source_dir, source, excluded_paths: List[str]=None):
         module_dependency_map, tf_definitions, dep_index_mapping = self.get_module_dependency_map(tf_definitions)
         module = self.get_new_module(source_dir, module_dependency_map, dep_index_mapping)
         self.add_tfvars(module, source)
@@ -444,7 +462,7 @@ class Parser:
         return module, module_dependency_map, tf_definitions
 
     @staticmethod
-    def _hcl_boolean_types_to_boolean(conf: dict) -> dict:
+    def _clean_parser_types(conf: dict) -> dict:
         sorted_keys = list(conf.keys())
         if len(conf.keys()) > 0 and all(isinstance(x, type(list(conf.keys())[0])) for x in conf.keys()):
             sorted_keys = sorted(filter(lambda x: x is not None, conf.keys()))
@@ -454,32 +472,42 @@ class Parser:
             if attribute == 'alias':
                 continue
             if isinstance(values, list):
-                sorted_conf[attribute] = Parser._hcl_boolean_types_to_boolean_lst(values)
+                sorted_conf[attribute] = Parser._clean_parser_types_lst(values)
             elif isinstance(values, dict):
-                sorted_conf[attribute] = Parser._hcl_boolean_types_to_boolean(conf[attribute])
+                sorted_conf[attribute] = Parser._clean_parser_types(conf[attribute])
             elif isinstance(values, str) and values in ('true', 'false'):
                 sorted_conf[attribute] = True if values == 'true' else False
+            elif isinstance(values, set):
+                sorted_conf[attribute] = Parser._clean_parser_types_lst(list(values))
+            elif isinstance(values, Tree):
+                sorted_conf[attribute] = str(values)
         return sorted_conf
 
     @staticmethod
-    def _hcl_boolean_types_to_boolean_lst(values: list) -> list:
+    def _clean_parser_types_lst(values: list) -> list:
         for i in range(len(values)):
             val = values[i]
             if isinstance(val, dict):
-                values[i] = Parser._hcl_boolean_types_to_boolean(val)
+                values[i] = Parser._clean_parser_types(val)
             elif isinstance(val, list):
-                values[i] = Parser._hcl_boolean_types_to_boolean_lst(val)
+                values[i] = Parser._clean_parser_types_lst(val)
             elif isinstance(val, str):
                 if val == 'true':
                     values[i] = True
                 elif val == 'false':
                     values[i] = False
+            elif isinstance(val, set):
+                values[i] = Parser._clean_parser_types_lst(list(val))
         str_values_in_lst = [val for val in values if isinstance(val, str)]
         str_values_in_lst.sort()
         result_values = [val for val in values if not isinstance(val, str)]
         result_values.extend(str_values_in_lst)
         return result_values
 
+    @staticmethod
+    def _serialize_definitions(tf_definitions):
+        return loads(dumps(tf_definitions, cls=DefinitionsEncoder))
+
     @staticmethod
     def get_next_vertices(evaluated_files: list, unevaluated_files: list) -> (list, list):
         """
@@ -570,7 +598,7 @@ class Parser:
 
     @staticmethod
     def get_new_module(source_dir, module_dependency_map, dep_index_mapping):
-        return Module(source_dir, module_dependency_map, dep_index_mapping, encode=False)
+        return Module(source_dir, module_dependency_map, dep_index_mapping)
 
     def add_tfvars(self, module, source):
         if not self.external_variables_data:
@@ -592,6 +620,7 @@ Load JSON or HCL, depending on filename.
     file_name = os.path.basename(file_path)
 
     try:
+        logging.debug(f"Parsing {file_path}")
         with open(file, "r") as f:
             if file_name.endswith(".json"):
                 return json.load(f)
@@ -603,7 +632,7 @@ Load JSON or HCL, depending on filename.
                 else:
                     return non_malformed_definitions
     except Exception as e:
-        logging.debug(f'failed while parsing file {file}', exc_info=e)
+        logging.debug(f'failed while parsing file {file_path}', exc_info=e)
         parsing_errors[file_path] = e
         return None
 
